import { summarize } from './objectDestructuring.js';

describe('the `summarize` function', () => {
  test('extracts an undefined type and undefined name from an empty object', () => {
    expect(summarize({})).toBe('Record of type undefined: undefined');
  });
  test('extracts a type from an object even if the object has no name', () => {
    expect(summarize({
      type: 'Foo',
    })).toBe('Record of type Foo: undefined');
  });
  test('extracts a name from an object even if the object has no type', () => {
    expect(summarize({
      name: 'Bar',
    })).toBe('Record of type undefined: Bar');
  });
  test('extracts a type and a name from an object with both', () => {
    expect(summarize({
      type: 'Foo',
      name: 'Bar',
    })).toBe('Record of type Foo: Bar');
  });
  test('extracts a type and a name from an object with those and other fields', () => {
    expect(summarize({
      type: 'Foo',
      name: 'Bar',
      value: Infinity,
    })).toBe('Record of type Foo: Bar');
  });
});
